#[non_exhaustive]pub enum CheckpointContents {
V1(CheckpointContentsV1),
}Expand description
The committed to contents of a checkpoint.
CheckpointContents contains a list of digests of Transactions, their
effects, and the user signatures that authorized their execution included in
a checkpoint.
BCS
The BCS serialized form for this type is defined by the following ABNF:
checkpoint-contents = %d00 checkpoint-contents-v1 ; variant 0Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Implementations
Sourceimpl CheckpointContents
impl CheckpointContents
pub fn digest(&self) -> CheckpointContentsDigest
hash and serde only.Sourceimpl CheckpointContents
impl CheckpointContents
pub fn new_v1(contents: CheckpointContentsV1) -> Self
Sourcepub fn as_v1(&self) -> &CheckpointContentsV1
pub fn as_v1(&self) -> &CheckpointContentsV1
Converts this into a v1 if it is a v1 variant, or panics otherwise.
Sourcepub fn as_mut_v1(&mut self) -> &mut CheckpointContentsV1
pub fn as_mut_v1(&mut self) -> &mut CheckpointContentsV1
Converts this into a mut v1 if it is a v1 variant, or panics otherwise.
Sourcepub fn as_opt_v1(&self) -> Option<&CheckpointContentsV1>
pub fn as_opt_v1(&self) -> Option<&CheckpointContentsV1>
Converts this into a v1 if it is a v1 variant, or returns None otherwise.
Sourcepub fn as_opt_mut_v1(&mut self) -> Option<&mut CheckpointContentsV1>
pub fn as_opt_mut_v1(&mut self) -> Option<&mut CheckpointContentsV1>
Converts this into a mut v1 if it is a v1 variant, or returns None otherwise.
Sourcepub fn into_opt_v1(self) -> Option<CheckpointContentsV1>
pub fn into_opt_v1(self) -> Option<CheckpointContentsV1>
Converts this into a v1 if it is a v1 variant, or returns None otherwise.
Sourcepub fn into_v1(self) -> CheckpointContentsV1
pub fn into_v1(self) -> CheckpointContentsV1
Converts this into a v1 if it is a v1 variant, or panics otherwise.
Sourcepub fn transactions(&self) -> &[CheckpointTransactionInfo]
pub fn transactions(&self) -> &[CheckpointTransactionInfo]
Returns a reference to the list of transactions in this checkpoint.
Sourcepub fn into_transactions(self) -> Vec<CheckpointTransactionInfo>
pub fn into_transactions(self) -> Vec<CheckpointTransactionInfo>
Consumes the CheckpointContentsV1 and returns the list of
transactions.