MoveAuthenticator

Enum MoveAuthenticator 

#[non_exhaustive]
pub enum MoveAuthenticator { V1(MoveAuthenticatorV1), }
MoveAuthenticator is a signature variant that enables a method of authentication through Move code. This type represents the data received by the Move authenticate function during the Account Abstraction authentication flow.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.

Implementations

Source

impl MoveAuthenticator

pub fn digest(&self) -> Digest

Available on crate features hash and serde only.
Source

impl MoveAuthenticator

pub fn from_bytes( bytes: impl AsRef<[u8]>, ) -> Result<Self, SignatureFromBytesError>

Available on crate feature serde only.
pub fn to_bytes(&self) -> Vec<u8>

Available on crate feature serde only.
Source

impl MoveAuthenticator

pub fn is_v1(&self) -> bool

Checks if this is a v1 variant.

pub fn as_v1(&self) -> &MoveAuthenticatorV1

Converts this into a v1 if it is a v1 variant, or panics otherwise.

pub fn as_mut_v1(&mut self) -> &mut MoveAuthenticatorV1

Converts this into a mut v1 if it is a v1 variant, or panics otherwise.

pub fn as_opt_v1(&self) -> Option<&MoveAuthenticatorV1>

Converts this into a v1 if it is a v1 variant, or returns None otherwise.

pub fn as_opt_mut_v1(&mut self) -> Option<&mut MoveAuthenticatorV1>

Converts this into a mut v1 if it is a v1 variant, or returns None otherwise.

pub fn into_opt_v1(self) -> Option<MoveAuthenticatorV1>

Converts this into a v1 if it is a v1 variant, or returns None otherwise.

pub fn into_v1(self) -> MoveAuthenticatorV1

Converts this into a v1 if it is a v1 variant, or panics otherwise.

pub fn version(&self) -> u64

Returns the version number of this authenticator variant.

pub fn address(&self) -> Address

Returns the address of the object being authenticated, which acts as the sender of the transaction.