pub struct ObjectDigest(/* private fields */);Expand description
The digest of an Object.
Implementations
Sourceimpl ObjectDigest
impl ObjectDigest
Sourcepub const LENGTH: usize = Digest::LENGTH
pub const LENGTH: usize = Digest::LENGTH
A constant representing the length of the digest in bytes.
Sourcepub const fn new(digest: [u8; 32]) -> Self
pub const fn new(digest: [u8; 32]) -> Self
Generates a new digest from the provided 32 byte array.
Sourcepub fn random_with<R>(rng: R) -> Self
Available on crate feature rand only.
pub fn random_with<R>(rng: R) -> Self
rand only.Generates a new digest from the provided random number generator.
Sourcepub const fn into_digest(self) -> Digest
pub const fn into_digest(self) -> Digest
Returns the underlying Digest.
Sourcepub const fn inner(&self) -> &[u8; 32]
pub const fn inner(&self) -> &[u8; 32]
Returns a reference to the inner array representation of this digest.
Sourcepub const fn into_inner(self) -> [u8; 32]
pub const fn into_inner(self) -> [u8; 32]
Returns the inner array representation of this digest.
Sourcepub fn from_base58<T: AsRef<[u8]>>(base58: T) -> Result<Self, DigestParseError>
pub fn from_base58<T: AsRef<[u8]>>(base58: T) -> Result<Self, DigestParseError>
Decodes a digest from a Base58 encoded string.
Sourcepub fn to_base58(&self) -> String
pub fn to_base58(&self) -> String
Returns a Base58 encoded string representation of this digest.
Sourcepub fn from_bytes(bytes: impl AsRef<[u8]>) -> Result<Self, DigestParseError>
pub fn from_bytes(bytes: impl AsRef<[u8]>) -> Result<Self, DigestParseError>
Generates a digest from bytes.
Sourcepub const fn next_lexicographical(&self) -> Self
pub const fn next_lexicographical(&self) -> Self
Returns the next digest in byte-increasing order.
Sourcepub const fn next_lexicographical_opt(&self) -> Option<Self>
pub const fn next_lexicographical_opt(&self) -> Option<Self>
Returns the next digest in byte-increasing order, or None if the
result would overflow.
Sourceimpl ObjectDigest
impl ObjectDigest
Sourcepub const OBJECT_DELETED: Self
pub const OBJECT_DELETED: Self
A marker that signifies the object is deleted.
Sourcepub const OBJECT_WRAPPED: Self
pub const OBJECT_WRAPPED: Self
A marker that signifies the object is wrapped into another object.
Sourcepub const OBJECT_CANCELED: Self
pub const OBJECT_CANCELED: Self
A marker that signifies the object is canceled.
Sourcepub fn is_alive(&self) -> bool
pub fn is_alive(&self) -> bool
Returns whether the digest represents an object that is neither deleted nor wrapped.
Sourcepub fn is_deleted(&self) -> bool
pub fn is_deleted(&self) -> bool
Returns whether the digest represents a deleted object.
Sourcepub fn is_wrapped(&self) -> bool
pub fn is_wrapped(&self) -> bool
Returns whether the digest represents an object wrapped in another object.