TransactionDigest

Struct TransactionDigest 

pub struct TransactionDigest(/* private fields */);
The digest of a Transaction.

Implementations

Source

impl TransactionDigest

pub const LENGTH: usize = Digest::LENGTH

A constant representing the length of the digest in bytes.

pub const ZERO: Self

A constant representing a zero digest.

pub const MIN: Self

The lexicographically minimum digest.

pub const MAX: Self

The lexicographically maximum digest.

pub const fn new(digest: [u8; 32]) -> Self

Generates a new digest from the provided 32 byte array.

pub fn random_with<R>(rng: R) -> Self
where R: RngCore + CryptoRng,

Available on crate feature rand only.

Generates a new digest from the provided random number generator.

pub fn random() -> Self

Available on crate feature rand only.

Generates a new random digest.

pub const fn as_digest(&self) -> &Digest

Returns a reference to the underlying Digest.

pub const fn into_digest(self) -> Digest

Returns the underlying Digest.

pub const fn inner(&self) -> &[u8; 32]

Returns a reference to the inner array representation of this digest.

pub const fn into_inner(self) -> [u8; 32]

Returns the inner array representation of this digest.

pub const fn as_bytes(&self) -> &[u8]

Returns a slice of bytes representing the digest.

pub fn from_base58<T: AsRef<[u8]>>(base58: T) -> Result<Self, DigestParseError>

Decodes a digest from a Base58 encoded string.

pub fn to_base58(&self) -> String

Returns a Base58 encoded string representation of this digest.

pub fn from_bytes(bytes: impl AsRef<[u8]>) -> Result<Self, DigestParseError>

Generates a digest from bytes.

pub const fn next_lexicographical(&self) -> Self

Returns the next digest in byte-increasing order.

pub const fn next_lexicographical_opt(&self) -> Option<Self>

Returns the next digest in byte-increasing order, or None if the result would overflow.

Source

impl TransactionDigest

pub const GENESIS_MARKER: Self = Self::ZERO

A digest used to signify the parent transaction was the genesis. Note that this is not the same as the digest of the genesis transaction, which cannot be known ahead of time.

pub const fn genesis_marker() -> Self

Returns the digest used to signify the parent transaction was the genesis.