pub struct TransactionEventsDigest(/* private fields */);Expand description
The digest of TransactionEvents.
Implementations
Sourceimpl TransactionEventsDigest
impl TransactionEventsDigest
Sourcepub const LENGTH: usize = Digest::LENGTH
pub const LENGTH: usize = Digest::LENGTH
A constant representing the length of the digest in bytes.
Sourcepub const fn new(digest: [u8; 32]) -> Self
pub const fn new(digest: [u8; 32]) -> Self
Generates a new digest from the provided 32 byte array.
Sourcepub fn random_with<R>(rng: R) -> Self
Available on crate feature rand only.
pub fn random_with<R>(rng: R) -> Self
rand only.Generates a new digest from the provided random number generator.
Sourcepub const fn into_digest(self) -> Digest
pub const fn into_digest(self) -> Digest
Returns the underlying Digest.
Sourcepub const fn inner(&self) -> &[u8; 32]
pub const fn inner(&self) -> &[u8; 32]
Returns a reference to the inner array representation of this digest.
Sourcepub const fn into_inner(self) -> [u8; 32]
pub const fn into_inner(self) -> [u8; 32]
Returns the inner array representation of this digest.
Sourcepub fn from_base58<T: AsRef<[u8]>>(base58: T) -> Result<Self, DigestParseError>
pub fn from_base58<T: AsRef<[u8]>>(base58: T) -> Result<Self, DigestParseError>
Decodes a digest from a Base58 encoded string.
Sourcepub fn to_base58(&self) -> String
pub fn to_base58(&self) -> String
Returns a Base58 encoded string representation of this digest.
Sourcepub fn from_bytes(bytes: impl AsRef<[u8]>) -> Result<Self, DigestParseError>
pub fn from_bytes(bytes: impl AsRef<[u8]>) -> Result<Self, DigestParseError>
Generates a digest from bytes.
Sourcepub const fn next_lexicographical(&self) -> Self
pub const fn next_lexicographical(&self) -> Self
Returns the next digest in byte-increasing order.
Sourcepub const fn next_lexicographical_opt(&self) -> Option<Self>
pub const fn next_lexicographical_opt(&self) -> Option<Self>
Returns the next digest in byte-increasing order, or None if the
result would overflow.