#[non_exhaustive]pub enum ObjectIn {
Missing,
Data {
version: Version,
digest: ObjectDigest,
owner: Owner,
},
}Expand description
State of an object prior to execution
If an object exists (at root-level) in the store prior to this transaction, it should be Data, otherwise it’s Missing, e.g. wrapped objects should be Missing.
BCS
The BCS serialized form for this type is defined by the following ABNF:
object-in = %d00 ; Missing
/ %d01 u64 object-digest owner ; DataVariants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Implementations
Sourceimpl ObjectIn
impl ObjectIn
Sourcepub fn is_missing(&self) -> bool
pub fn is_missing(&self) -> bool
Checks if this is a missing variant.
pub fn opt_version(&self) -> Option<Version>
pub fn version(&self) -> Version
pub fn opt_digest(&self) -> Option<ObjectDigest>
pub fn digest(&self) -> ObjectDigest
pub fn opt_owner(&self) -> Option<Owner>
pub fn owner(&self) -> Owner