pub struct ChangedObject {
pub object_id: ObjectId,
pub input_state: ObjectIn,
pub output_state: ObjectOut,
pub id_operation: IdOperation,
}Expand description
Input/output state of an object that was changed during execution
BCS
The BCS serialized form for this type is defined by the following ABNF:
changed-object = object-id object-in object-out id-operationFields
object_id: ObjectIdId of the object
input_state: ObjectInState of the object in the store prior to this transaction.
output_state: ObjectOutState of the object in the store after this transaction.
id_operation: IdOperationWhether this object ID is created or deleted in this transaction. This information isn’t required by the protocol but is useful for providing more detailed semantics on object changes.