pub enum ObjectType {
Package,
Struct(StructTag),
}Expand description
Type of an IOTA object
Variants
Package
Move package containing one or more bytecode modules
Struct(StructTag)
A Move struct of the given type
Implementations
Sourceimpl ObjectType
impl ObjectType
Sourcepub fn is_package(&self) -> bool
pub fn is_package(&self) -> bool
Checks if this is a package variant.
Sourcepub fn as_struct(&self) -> &StructTag
pub fn as_struct(&self) -> &StructTag
Converts this into a struct if it is a struct variant, or panics otherwise.
Sourcepub fn as_mut_struct(&mut self) -> &mut StructTag
pub fn as_mut_struct(&mut self) -> &mut StructTag
Converts this into a mut struct if it is a struct variant, or panics otherwise.
Sourcepub fn as_opt_struct(&self) -> Option<&StructTag>
pub fn as_opt_struct(&self) -> Option<&StructTag>
Converts this into a struct if it is a struct variant, or returns None otherwise.
Sourcepub fn as_opt_mut_struct(&mut self) -> Option<&mut StructTag>
pub fn as_opt_mut_struct(&mut self) -> Option<&mut StructTag>
Converts this into a mut struct if it is a struct variant, or returns None otherwise.
Sourcepub fn into_opt_struct(self) -> Option<StructTag>
pub fn into_opt_struct(self) -> Option<StructTag>
Converts this into a struct if it is a struct variant, or returns None otherwise.
Sourcepub fn into_struct(self) -> StructTag
pub fn into_struct(self) -> StructTag
Converts this into a struct if it is a struct variant, or panics otherwise.