pub struct ObjectReference {
pub object_id: ObjectId,
pub version: Version,
pub digest: ObjectDigest,
}Expand description
Reference to an object
Contains sufficient information to uniquely identify a specific object.
BCS
The BCS serialized form for this type is defined by the following ABNF:
object-reference = object-id u64 object-digestFields
object_id: ObjectIdThe object id of this object.
version: VersionThe version of this object.
digest: ObjectDigestThe digest of this object.
Implementations
Sourceimpl ObjectReference
impl ObjectReference
Sourcepub const fn new(
object_id: ObjectId,
version: Version,
digest: ObjectDigest,
) -> Self
pub const fn new( object_id: ObjectId, version: Version, digest: ObjectDigest, ) -> Self
Creates a new object reference from the object’s id, version, and digest.
Sourcepub fn object_id(&self) -> &ObjectId
pub fn object_id(&self) -> &ObjectId
Returns a reference to the object id that this ObjectReference is referring to.
Sourcepub fn version(&self) -> Version
pub fn version(&self) -> Version
Returns the version of the object that this ObjectReference is referring to.
Sourcepub fn digest(&self) -> &ObjectDigest
pub fn digest(&self) -> &ObjectDigest
Returns the digest of the object that this ObjectReference is referring to.
Sourcepub fn into_parts(self) -> (ObjectId, Version, ObjectDigest)
pub fn into_parts(self) -> (ObjectId, Version, ObjectDigest)
Returns a 3-tuple containing the object id, version, and digest.