pub struct RandomnessStateUpdate {
pub epoch: u64,
pub randomness_round: RandomnessRound,
pub random_bytes: Vec<u8>,
pub randomness_obj_initial_shared_version: Version,
}Expand description
Randomness update
BCS
The BCS serialized form for this type is defined by the following ABNF:
randomness-state-update = u64 randomness-round bytes versionFields
epoch: u64Epoch of the randomness state update transaction
randomness_round: RandomnessRoundRandomness round of the update
random_bytes: Vec<u8>Updated random bytes
The initial version of the randomness object that it was shared at.