#[non_exhaustive]pub enum ObjectOut {
Missing,
ObjectWrite {
digest: ObjectDigest,
owner: Owner,
},
PackageWrite {
version: Version,
digest: ObjectDigest,
},
}Expand description
State of an object after execution
BCS
The BCS serialized form for this type is defined by the following ABNF:
object-out = %d00 ; Missing
/ %d01 object-digest owner ; ObjectWrite
/ %d02 u64 object-digest ; PackageWriteVariants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Missing
Same definition as in ObjectIn.
ObjectWrite
Any written object, including all of mutated, created, unwrapped today.
PackageWrite
Packages writes need to be tracked separately with version because we don’t use lamport version for package publish and upgrades.
Implementations
Sourceimpl ObjectOut
impl ObjectOut
Sourcepub fn is_missing(&self) -> bool
pub fn is_missing(&self) -> bool
Checks if this is a missing variant.
Sourcepub fn is_object_write(&self) -> bool
pub fn is_object_write(&self) -> bool
Checks if this is a object_write variant.
Sourcepub fn is_package_write(&self) -> bool
pub fn is_package_write(&self) -> bool
Checks if this is a package_write variant.
pub fn opt_object_digest(&self) -> Option<ObjectDigest>
pub fn object_digest(&self) -> ObjectDigest
pub fn opt_object_owner(&self) -> Option<Owner>
pub fn object_owner(&self) -> Owner
pub fn opt_package_version(&self) -> Option<Version>
pub fn package_version(&self) -> Version
pub fn opt_package_digest(&self) -> Option<ObjectDigest>
pub fn package_digest(&self) -> ObjectDigest